#
# spec file for package nethogs
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2013 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nethogs
Version:        0.8.8
Release:        1.2
Summary:        Network Bandwidth Usage Monitor
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Diagnostic
URL:            https://raboof.github.io/nethogs/
Source:         https://github.com/raboof/nethogs/archive/v%{version}/nethogs-v%{version}.tar.gz
Source3:        https://keybase.io/raboof/key.asc#/%{name}.keyring
BuildRequires:  gcc-c++
BuildRequires:  libpcap-devel
BuildRequires:  ncurses-devel

%description
NetHogs is a small 'net top' tool. Instead of breaking the traffic down per
protocol or per subnet, like most tools do, it groups bandwidth by process.
NetHogs does not rely on a special kernel module to be loaded. If there's
suddenly a lot of network traffic, you can fire up NetHogs and immediately see
which PID is causing this. This makes it easy to indentify programs that have
gone wild and are suddenly taking up your bandwidth.

%prep
%autosetup -p1

%build
%make_build \
    sbin="%{_sbindir}" \
    bin="%{_sbindir}" \
    man8="%{_mandir}/man8" \
    CFLAGS="%{optflags}" \
    CXXFLAGS="%{optflags}" \
    CXX="g++" \
    nethogs

%install
make  %{?_smp_mflags} \
    sbin="%{buildroot}%{_sbindir}" \
    bin="%{buildroot}%{_sbindir}" \
    man8="%{buildroot}%{_mandir}/man8" \
    CFLAGS="%{optflags}" \
    CXXFLAGS="%{optflags}" \
    CXX="g++" \
    install

%check
%make_build test

%files
%license COPYING
%doc README.md DESIGN
%{_sbindir}/nethogs
%{_mandir}/man8/nethogs.8%{?ext_man}

%changelog
* Tue Dec 10 2024 pgajdos@suse.com
- version update to 0.8.8
  * Fix that on ubuntu 20.04, the current version of the code does not compile as a python package by @molysgaard in #224
  * Add -std=c++14 for application build by @msbit in #228
  * Hide cursor during initialization and restore at exit by @zevweiss in #231
  * Capabilities for reading process names by @qouoq in #233
  * Additional useful capabilities by @qouoq in #234
  * Add -std=c++14 for application build by @NeilZhy in #236
  * Use s instead of sec for units of seconds by @a1346054 in #242
  * Add Arch Linux instructions to README.md by @orhun in #250
  * Fix wrong extern declaration of pidsToWatch by @sgtcortez in #251
  * fix get_devlen function from being pointless by @DiedByDisgust in #255
  * fix python bindings by @AndreasGocht in #258
  * Report only changes of send and received data by @AndreasGocht in #260
  * Clarify units by @hramrach in #262
  * fix an copy-and-paste error in the bindings by @AndreasGocht in #263
  * Report pcap stas by @AndreasGocht in #264
  * Fix nethogsmonitor_loop_devices_py to accept more than one device by @AndreasGocht in #267
  * allow the library to enable UDP recording by @AndreasGocht in #269
  * Add meson buildsystem by @lleon95 in #275
  * determineVersion.sh: prevent traversing into outer git repo for git-describe call by @BubuOT in #279
* Sun Apr 10 2022 Dirk Müller <dmueller@suse.com>
- update to 0.8.7:
  * Adding ppc64le architecture support on travis-ci by @kishorkunal-raj in #198
  * Issue: #62 - UDP support by @takeoverjp in #199
  * Update man page with the latest help message. by @takeoverjp in #200
  * Issue: #102 - Show screenshot in README. by @takeoverjp in #201
  * Add links to other network traffic monitoring tools. by @takeoverjp in #202
  * Issue: #96 - Garbage collect inodeproc on each ui refresh. by @takeoverjp in #203
  * Fix compilation error with [-Werror=format-security] by @kretcheu in #210
  * Added BusyTasks link to the list by @unknown-spirit in #212
  * Add bandwhich and sniffer links by @chenjiandongx in #213
  * Disable capability check, handle failure better by @ncfavier in #215
  * feat: Add basename support #155 by @sgtcortez in #216
  * Use "--tags" parameter to get the correct git-tag by @schuellerf in #221
  * Add process filter by @sgtcortez in #218
  * Add python bindings by @jimmylomro in #222
  * Improve performance with many connections by @CyberShadow in #223
* Sat Sep 12 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.8.6:
  * fix: Expose to_ms / packet buffer timeout to libnethogs
  * Add MB/s and GB/s view modes
  * Fix libnethogs handle memory leak
  * add support for pcap capture filters
  * Add "how to run without root" (capabilities note) to README
  * Remove confusing 'waiting for first packet' message
* Mon Oct 10 2016 astieger@suse.com
- update to 0.8.5 (bsc#1003837):
  * documentation updates
  * support for multiple IP addresses on one device
  * various bug fixes and UI fixes
- drop print_opendir_warnings_only_in_bughunt_mode.patch, upstream
* Wed Jan  6 2016 manfred99@gmx.ch
- Add print_opendir_warnings_only_in_bughunt_mode.patch:
  * upstream patch to suppress nonsensical warning
- update to 0.8.1:
  * Fixed buffer overflow for cmdline strings of length >= 80
  * fix creating socket by using normal DGRAM sockets (bsc#970024)
  * correctly display PID's up to 7 characters
  * Get all running non-loopback devices by default
  * take into account the terminal height when printing the 'total' row
  * added new command line switches -s, -c, -v
  * changed needrefresh default value from true to false
* Tue Aug  4 2015 mpluskal@suse.com
- Use url for source
- Cleanup spec file with spec-cleaner
* Wed Oct 16 2013 pwieczorkiewicz@suse.com
- correct nethogs.spec file with the spec-cleaner
* Sat Aug 27 2011 pascal.bleser@opensuse.org
- update to 0.8.0:
  * adds support for wider terminals was added
  * set view mode to 'kbps' by default, instead of the 'grand total' number of
    bytes
* Mon May 16 2011 pascal.bleser@opensuse.org
- initial version (0.7.0)
